@@ -15,7 +15,6 @@ from d3m.primitive_interfaces.base import CallResult
 # from . import __version__
 
 
-
 Inputs = container.ndarray
 Outputs = container.ndarray
 
@@ -53,12 +52,12 @@ class IPCMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
             {
                 'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_feature_selection_toolbox',
-                'version': '2.1.2'
+                'version': '2.1.3'
             },
             {
                 'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_featureSelection_python_tools',
-                'version': '2.2.0'
+                'version': '2.2.1'
             }
         ],
         'python_path': 'd3m.primitives.rpi_featureSelection_python_tools.IPCMBplus_Selector',
@@ -67,8 +66,7 @@ class IPCMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
         ],
         'primitive_family': metadata_base.PrimitiveFamily.FEATURE_SELECTION,
         'preconditions': [
-            "NO_CATEGORICAL_VALUES",
-            "NO_MISSING_VALUES"
+            "NO_CATEGORICAL_VALUES"
         ]
     })
 
@@ -94,10 +92,11 @@ class IPCMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
             raise ValueError('Missing training data, or missing values exist.')
 
         scipy.io.savemat('rpi_data.mat', mdict={'traindata': self._training_inputs, 'trainlabel': self._training_outputs})
-        dir_path = os.path.dirname(os.path.realpath('rpi_data.mat'))        
+        #dir_path = os.path.dirname(os.path.realpath('rpi_data.mat'))        
 
         a = rpi_feature_selection_toolbox.initialize()
-        index = np.reshape(np.array(a.IPCMBplus(dir_path)), [-1, ])
+        index = np.reshape(np.array(a.IPCMBplus()), [-1, ])
+        #index = np.reshape(np.array(a.IPCMBplus(dir_path)), [-1, ])
         self._index = (index - 1).astype(int)
         self._fitted = True
 
@@ -136,20 +135,19 @@ class JMIplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, H
             {
                 'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_feature_selection_toolbox',
-                'version': '2.1.2'
+                'version': '2.1.3'
             },
             {
                 'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_featureSelection_python_tools',
-	            'version': '2.2.0'
+	            'version': '2.2.1'
             }
         ],
         'python_path': 'd3m.primitives.rpi_featureSelection_python_tools.JMIplus_Selector',
         'algorithm_types': ['MINIMUM_REDUNDANCY_FEATURE_SELECTION'],
         'primitive_family': 'FEATURE_SELECTION',
         'preconditions': [
-            "NO_CATEGORICAL_VALUES",
-            "NO_MISSING_VALUES"
+            "NO_CATEGORICAL_VALUES"
         ]
     })
 
@@ -175,10 +173,11 @@ class JMIplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, H
             raise ValueError('Missing training data, or missing values exist.')
 
         scipy.io.savemat('rpi_data.mat', mdict={'traindata': self._training_inputs, 'trainlabel': self._training_outputs})
-        dir_path = os.path.dirname(os.path.realpath('rpi_data.mat'))
+        #dir_path = os.path.dirname(os.path.realpath('rpi_data.mat'))
 
         a = rpi_feature_selection_toolbox.initialize()
-        index = np.reshape(np.array(a.JMIplus(dir_path)), [-1, ])
+        #index = np.reshape(np.array(a.JMIplus(dir_path)), [-1, ])
+        index = np.reshape(np.array(a.JMIplus()), [-1, ])
 
         self._index = (index - 1).astype(int)
         self._fitted = True
@@ -218,20 +217,19 @@ class STMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
             {
                 'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_feature_selection_toolbox',
-                'version': '2.1.2'
+                'version': '2.1.3'
             },
             {
                 'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_featureSelection_python_tools',
-	            'version': '2.2.0'
+	            'version': '2.2.1'
             }
         ],
         'python_path': 'd3m.primitives.rpi_featureSelection_python_tools.STMBplus_Selector',
         'algorithm_types': ['MINIMUM_REDUNDANCY_FEATURE_SELECTION'],
         'primitive_family': 'FEATURE_SELECTION',
         'preconditions': [
-            "NO_CATEGORICAL_VALUES",
-            "NO_MISSING_VALUES"
+            "NO_CATEGORICAL_VALUES"
         ]
     })
 
@@ -257,11 +255,14 @@ class STMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
             raise ValueError('Missing training data, or missing values exist.')
         
         scipy.io.savemat('rpi_data.mat', mdict={'traindata': self._training_inputs, 'trainlabel': self._training_outputs})
-        dir_path = os.path.dirname(os.path.realpath('rpi_data.mat'))        
+        #dir_path = os.path.dirname(os.path.realpath('rpi_data.mat'))        
 
         a = rpi_feature_selection_toolbox.initialize()
-        index = np.reshape(np.array(a.STMBplus(dir_path)), [-1, ])
-
+        #index = np.reshape(np.array(a.STMBplus(dir_path)), [-1, ])
+        index = np.reshape(np.array(a.STMBplus()), [-1, ])
+        #print('\n')
+        #print(index)
+        #print('\n')
         self._index = (index - 1).astype(int)
         self._fitted = True
 
@@ -300,20 +301,19 @@ class aSTMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
             {
                 'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_feature_selection_toolbox',
-                'version': '2.1.2'
+                'version': '2.1.3'
             },
             {
                 'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_featureSelection_python_tools',
-	            'version': '2.2.0'
+	            'version': '2.2.1'
             }
         ],
         'python_path': 'd3m.primitives.rpi_featureSelection_python_tools.aSTMBplus_Selector',
         'algorithm_types': ['MINIMUM_REDUNDANCY_FEATURE_SELECTION'],
         'primitive_family': 'FEATURE_SELECTION',
         'preconditions': [
-            "NO_CATEGORICAL_VALUES",
-            "NO_MISSING_VALUES"
+            "NO_CATEGORICAL_VALUES"
         ]
     })
 
@@ -339,10 +339,11 @@ class aSTMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
             raise ValueError('Missing training data, or missing values exist.')
 
         scipy.io.savemat('rpi_data.mat', mdict={'traindata': self._training_inputs, 'trainlabel': self._training_outputs})
-        dir_path = os.path.dirname(os.path.realpath('rpi_data.mat'))
+        #dir_path = os.path.dirname(os.path.realpath('rpi_data.mat'))
 
         a = rpi_feature_selection_toolbox.initialize()
-        index = np.reshape(np.array(a.aSTMBplus(dir_path)), [-1, ])
+        #index = np.reshape(np.array(a.aSTMBplus(dir_path)), [-1, ])
+        index = np.reshape(np.array(a.aSTMBplus()), [-1, ])
 
         self._index = (index - 1).astype(int)
         self._fitted = True
@@ -382,20 +383,19 @@ class sSTMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
             {
                 'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_feature_selection_toolbox',
-                'version': '2.1.2'
+                'version': '2.1.3'
             },
             {
                 'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_featureSelection_python_tools',
-	            'version': '2.2.0'
+	            'version': '2.2.1'
             }
         ],
         'python_path': 'd3m.primitives.rpi_featureSelection_python_tools.sSTMBplus_Selector',
         'algorithm_types': ['MINIMUM_REDUNDANCY_FEATURE_SELECTION'],
         'primitive_family': 'FEATURE_SELECTION',
         'preconditions': [
-            "NO_CATEGORICAL_VALUES",
-            "NO_MISSING_VALUES"
+            "NO_CATEGORICAL_VALUES"
         ]
     })
 
@@ -421,11 +421,11 @@ class sSTMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
             raise ValueError('Missing training data, or missing values exist.')
 
         scipy.io.savemat('rpi_data.mat', mdict={'traindata': self._training_inputs, 'trainlabel': self._training_outputs})
-        dir_path = os.path.dirname(os.path.realpath('rpi_data.mat'))
+        #dir_path = os.path.dirname(os.path.realpath('rpi_data.mat'))
 
         a = rpi_feature_selection_toolbox.initialize()
-        index = np.reshape(np.array(a.sSTMBplus(dir_path)), [-1, ])
-
+        #index = np.reshape(np.array(a.sSTMBplus(dir_path)), [-1, ])
+        index = np.reshape(np.array(a.sSTMBplus()), [-1, ])
         self._index = (index - 1).astype(int)
         self._fitted = True
 
@@ -464,20 +464,19 @@ class pSTMB_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, Hyp
             {
                 'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_feature_selection_toolbox',
-                'version': '2.1.2'
+                'version': '2.1.3'
             },
             {
                 'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_featureSelection_python_tools',
-	            'version': '2.2.0'
+	            'version': '2.2.1'
             }
         ],
         'python_path': 'd3m.primitives.rpi_featureSelection_python_tools.pSTMB_Selector',
         'algorithm_types': ['MINIMUM_REDUNDANCY_FEATURE_SELECTION'],
         'primitive_family': 'FEATURE_SELECTION',
         'preconditions': [
-            "NO_CATEGORICAL_VALUES",
-            "NO_MISSING_VALUES"
+            "NO_CATEGORICAL_VALUES"
         ]
     })
 
@@ -503,10 +502,11 @@ class pSTMB_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, Hyp
             raise ValueError('Missing training data, or missing values exist.')
 
         scipy.io.savemat('rpi_data.mat', mdict={'traindata': self._training_inputs, 'trainlabel': self._training_outputs})
-        dir_path = os.path.dirname(os.path.realpath('rpi_data.mat'))
+        #dir_path = os.path.dirname(os.path.realpath('rpi_data.mat'))
 
         a = rpi_feature_selection_toolbox.initialize()
-        index = np.reshape(np.array(a.pSTMB(dir_path)), [-1, ])
+        #index = np.reshape(np.array(a.pSTMB(dir_path)), [-1, ])
+        index = np.reshape(np.array(a.pSTMB()), [-1, ])
 
         self._index = (index - 1).astype(int)
         self._fitted = True
@@ -545,20 +545,19 @@ class F_STMB_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, Hy
             {
                 'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_feature_selection_toolbox',
-                'version': '2.1.2'
+                'version': '2.1.3'
             },
             {
                 'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_featureSelection_python_tools',
-	            'version': '2.2.0'
+	            'version': '2.2.1'
             }
         ],
         'python_path': 'd3m.primitives.rpi_featureSelection_python_tools.F_STMB_Selector',
         'algorithm_types': ['MINIMUM_REDUNDANCY_FEATURE_SELECTION'],
         'primitive_family': 'FEATURE_SELECTION',
         'preconditions': [
-            "NO_CATEGORICAL_VALUES",
-            "NO_MISSING_VALUES"
+            "NO_CATEGORICAL_VALUES"
         ]
     })
 
@@ -584,11 +583,12 @@ class F_STMB_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, Hy
             raise ValueError('Missing training data, or missing values exist.')
 
         scipy.io.savemat('rpi_data.mat', mdict={'traindata': self._training_inputs, 'trainlabel': self._training_outputs})
-        dir_path = os.path.dirname(os.path.realpath('rpi_data.mat'))
+        #dir_path = os.path.dirname(os.path.realpath('rpi_data.mat'))
 
         a = rpi_feature_selection_toolbox.initialize()
-        index = np.reshape(np.array(a.F_STMB(dir_path)), [-1, ])
-
+        #index = np.reshape(np.array(a.F_STMB(dir_path)), [-1, ])
+        index = np.reshape(np.array(a.F_STMB()), [-1, ])
+ 
         self._index = (index - 1).astype(int)
         self._fitted = True
 
@@ -628,20 +628,19 @@ class F_aSTMB_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, H
             {
                 'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_feature_selection_toolbox',
-                'version': '2.1.2'
+                'version': '2.1.3'
             },
             {
                 'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_featureSelection_python_tools',
-	            'version': '2.2.0'
+	            'version': '2.2.1'
             }
         ],
         'python_path': 'd3m.primitives.rpi_featureSelection_python_tools.F_aSTMB_Selector',
         'algorithm_types': ['MINIMUM_REDUNDANCY_FEATURE_SELECTION'],
         'primitive_family': 'FEATURE_SELECTION',
         'preconditions': [
-            "NO_CATEGORICAL_VALUES",
-            "NO_MISSING_VALUES"
+            "NO_CATEGORICAL_VALUES"
         ]
     })
 
@@ -667,10 +666,11 @@ class F_aSTMB_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, H
             raise ValueError('Missing training data, or missing values exist.')
 
         scipy.io.savemat('rpi_data.mat', mdict={'traindata': self._training_inputs, 'trainlabel': self._training_outputs})
-        dir_path = os.path.dirname(os.path.realpath('rpi_data.mat'))
+        #dir_path = os.path.dirname(os.path.realpath('rpi_data.mat'))
 
         a = rpi_feature_selection_toolbox.initialize()
-        index = np.reshape(np.array(a.F_aSTMB(dir_path)), [-1, ])
+        #index = np.reshape(np.array(a.F_aSTMB(dir_path)), [-1, ])
+        index = np.reshape(np.array(a.F_aSTMB()), [-1, ])
 
         self._index = (index - 1).astype(int)
         self._fitted = True
@@ -710,20 +710,19 @@ class F_sSTMB_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, H
             {
                 'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_feature_selection_toolbox',
-                'version': '2.1.2'
+                'version': '2.1.3'
             },
             {
                 'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_featureSelection_python_tools',
-	            'version': '2.2.0'
+	            'version': '2.2.1'
             }
         ],
         'python_path': 'd3m.primitives.rpi_featureSelection_python_tools.F_sSTMB_Selector',
         'algorithm_types': ['MINIMUM_REDUNDANCY_FEATURE_SELECTION'],
         'primitive_family': 'FEATURE_SELECTION',
         'preconditions': [
-            "NO_CATEGORICAL_VALUES",
-            "NO_MISSING_VALUES"
+            "NO_CATEGORICAL_VALUES"
         ]
     })
 
@@ -749,10 +748,11 @@ class F_sSTMB_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, H
             raise ValueError('Missing training data, or missing values exist.')
 
         scipy.io.savemat('rpi_data.mat', mdict={'traindata': self._training_inputs, 'trainlabel': self._training_outputs})
-        dir_path = os.path.dirname(os.path.realpath('rpi_data.mat'))
+        #dir_path = os.path.dirname(os.path.realpath('rpi_data.mat'))
 
         a = rpi_feature_selection_toolbox.initialize()
-        index = np.reshape(np.array(a.F_sSTMB(dir_path)), [-1, ])
+        #index = np.reshape(np.array(a.F_sSTMB(dir_path)), [-1, ])
+        index = np.reshape(np.array(a.F_sSTMB()), [-1, ])
 
         self._index = (index - 1).astype(int)
         self._fitted = True
@@ -792,20 +792,19 @@ class JMIp_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, Hype
             {
                 'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_feature_selection_toolbox',
-                'version': '2.1.2'
+                'version': '2.1.3'
             },
             {
                 'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_featureSelection_python_tools',
-	            'version': '2.2.0'
+	            'version': '2.2.1'
             }
         ],
         'python_path': 'd3m.primitives.rpi_featureSelection_python_tools.JMIp_Selector',
         'algorithm_types': ['MINIMUM_REDUNDANCY_FEATURE_SELECTION'],
         'primitive_family': 'FEATURE_SELECTION',
         'preconditions': [
-            "NO_CATEGORICAL_VALUES",
-            "NO_MISSING_VALUES"
+            "NO_CATEGORICAL_VALUES"
         ]
     })
 
@@ -831,10 +830,11 @@ class JMIp_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, Hype
             raise ValueError('Missing training data, or missing values exist.')
 
         scipy.io.savemat('rpi_data.mat', mdict={'traindata': self._training_inputs, 'trainlabel': self._training_outputs})
-        dir_path = os.path.dirname(os.path.realpath('rpi_data.mat'))
+        #dir_path = os.path.dirname(os.path.realpath('rpi_data.mat'))
 
         a = rpi_feature_selection_toolbox.initialize()
-        index = np.reshape(np.array(a.JMIp(dir_path)), [-1, ])
+        #index = np.reshape(np.array(a.JMIp(dir_path)), [-1, ])
+        index = np.reshape(np.array(a.JMIp()), [-1, ])
 
         self._index = (index - 1).astype(int)
         self._fitted = True
